/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id:LoaderManager.java 10822 2007-07-04 08:26:06Z durieuxp $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.lib.bootstrap;

import java.io.File;

import org.ow2.jonas.empty.Empty;
import org.ow2.jonas.lib.bootstrap.loader.JClassLoader;

/**
 * This class create all ClassLoaders necessary for JOnAS/OSGi.
 * @author Francois Fornaciari
 */
public class OSGiLoaderManager extends LoaderManager {

    /**
     * External ClassLoader.
     */
    private JClassLoader externalClassLoader = null;

    /**
     * $JONAS_ROOT.
     */
    private String jonasRoot = null;

    /**
     * $JONAS_BASE.
     */
    private String jonasBase = null;

    /**
     * $JONAS_ROOT/lib/ext.
     */
    private File jonasRootLibExt;
    
    /**
     * Relative external library path : lib/ext 
     */
    private static final String LIB_EXTERNAL = "lib" + File.separator + "ext";
    
    /**
     * Initialize main directories.
     */
    public OSGiLoaderManager() {
        jonasRoot = JProp.getJonasRoot();
        jonasBase = JProp.getJonasBase();
        jonasRootLibExt = new File(jonasRoot, LIB_EXTERNAL);
    }

    /**
     * Initialize the LoaderManager with a JProp instance.
     * @param props JProp used to configure JOnAS
     */
    public void init(final JProp props) { 
        // Do nothing
    }
    
    /**
     * @return Returns the External ClassLoader which contains user libraries.
     * @throws Exception When ClassLoader cannot be created.
     */
    public JClassLoader getExternalLoader() throws Exception {
        if (externalClassLoader == null) {
            externalClassLoader = createExternalClassLoader();
        }
        return externalClassLoader;
    }
    
    /**
     * Constructs the External ClassLoader.
     *
     * @return Returns the External ClassLoader.
     * @throws Exception When ClassLoader cannot be created from CLASSPATH or resources cannot be added to URLs List.
     */
    private JClassLoader createExternalClassLoader() throws Exception {
        JURLs jurls = new JURLs();

        // Load $JONAS_ROOT/lib/ext/*.jar
        jurls.add(jonasRootLibExt, ".jar");

        // Add $JONAS_BASE/lib/ext only if $JONAS_BASE != $JONAS_ROOT
        // $JONAS_BASE/lib/ext is added before $JONAS_ROOT/lib/ext
        if (!jonasRoot.toLowerCase().equals(jonasBase.toLowerCase())) {
            File jonasBaseLibExt = new File(jonasBase, LIB_EXTERNAL);
            if (jonasBaseLibExt.exists()) {
                jurls.add(jonasBaseLibExt, ".jar");
            }
        }

        // Empty class is in an OSGi bundle, so that its ClassLoader
        // will benefits of OSGi properties (Dynamic-Import, ...)
        return new JClassLoader("External", jurls.toURLs(), Empty.class.getClassLoader());
    }
    
    /**
     * @return Returns the Commons ClassLoader
     * @throws Exception When ClassLoader cannot be created.
     * @deprecated
     */
    @Deprecated
    public JClassLoader getCommonsLoader() throws Exception {
        return getExternalLoader();
    }

    /**
     * @return Returns the Tools ClassLoader
     * @throws Exception When ClassLoader cannot be created.
     * @deprecated
     */
    @Deprecated
    public JClassLoader getToolsLoader() throws Exception {
        return getExternalLoader();
    }
    
    /**
     * @return Returns the Application ClassLoader
     * @throws Exception When ClassLoader cannot be created.
     * @deprecated
     */
    @Deprecated
    public JClassLoader getAppsLoader() throws Exception {
        return getExternalLoader();
    }

    /**
     * @return Returns the Catalina ClassLoader
     * @throws Exception When ClassLoader cannot be created.
     * @deprecated
     */
    @Deprecated
    public JClassLoader getCatalinaLoader() throws Exception {
        return getExternalLoader();
    }

}